/*
ScheduleTogether Backend
Copyright (C) 2024, Zervó Zadachin

DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License version 3
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License version 3 for more details.

This program incorporates external libraries for certain functionalities.
These libraries are covered by their respective licenses, and their usage
agreements are as outlined in their respective documentation or source
code.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package main

import (
	"fmt"
	"log"

	"git.zervo.org/scheduletogether/scheduletogetherbackend/internal/api"
	"git.zervo.org/scheduletogether/scheduletogetherbackend/pkg/helpers/config"
)

// main starts the server
func main() {
	// Load configuration
	cfg, err := config.LoadConfig()
	if err != nil {
		log.Fatal(err)
	}

	// Create Iris server instance
	app := api.NewServer()

	// Start the server
	addr := fmt.Sprintf(":%d", cfg.ServerPort) // Assuming port is in config
	log.Printf("Starting server on address: %s\n", addr)
	if err := app.Listen(addr); err != nil {
		log.Fatal(err)
	}
}
