/*
ScheduleTogether Backend
Copyright (C) 2024, Zervó Zadachin

DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License version 3
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License version 3 for more details.

This program incorporates external libraries for certain functionalities.
These libraries are covered by their respective licenses, and their usage
agreements are as outlined in their respective documentation or source
code.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package database

import (
	"fmt"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"

	"git.zervo.org/scheduletogether/scheduletogetherbackend/pkg/helpers/config"
	"git.zervo.org/scheduletogether/scheduletogetherbackend/pkg/helpers/logging"
)

var logboi = logging.NewLogger("database")

var Db *gorm.DB

// Init initializes the database
func Init() error {
	// Load configuration
	cfg, err := config.LoadConfig()
	if err != nil {
		logboi.Err("Failed to read configuration: " + err.Error())
		return err
	}

	// Connect to database
	switch dialect := cfg.DatabaseDialect; dialect {
	case "sqlite":
		Db, err = gorm.Open(sqlite.Open("test.db"), &gorm.Config{})
	default:
		logboi.Err("Unsupported database dialect: " + dialect)
		return fmt.Errorf("unsupported database dialect: %s", dialect)
	}
	if err != nil {
		logboi.Err("Failed to connect to database: " + err.Error())
		return err
	}

	// Migrate database models
	Db.AutoMigrate(&User{})
	Db.AutoMigrate(&FriendRequest{})
	Db.AutoMigrate(&RegisterVerification{})
	Db.AutoMigrate(&Schedule{})
	Db.AutoMigrate(&Gateway{})

	return nil
}
